linch-pin
----------

Linch-pin provides a collection of Ansible playbooks for provisioning and
managing resources across multiple infrastructures. Where multiple
infrastructure resource types can be defined with a single topology file.

Linch-pin can also generate inventory files for use with additional ansible
playbooks. These are applied using an inventory layout file (work in progress).

Contributing
++++++++++++

Developers are encouraged to contribute to the Linch-Pin project. Please visit
`Contributing <http://github.com/CentOS-PaaS-SIG/linch-pin/tree/develop/CONTRIBUTING.rst>`_
for details.

Installation
++++++++++++

`Installation documentation <http://linch-pin.readthedocs.io/en/latest/intro_installation.html>`_

General Configuration
+++++++++++++++++++++

`General Configuration documentation <http://linch-pin.readthedocs.io/en/latest/config_general.html>`_

Credentials
++++++++++++

* `Openstack credentials examples <https://github.com/CentOS-PaaS-SIG/linch-pin/tree/develop/linchpin/provision/roles/openstack/vars>`_
* `AWS credential examples <https://github.com/CentOS-PaaS-SIG/linch-pin/tree/develop/cli_cleanup/linchpin/provision/roles/aws/vars>`_
* `GCE credentials examples <https://github.com/CentOS-PaaS-SIG/linch-pin/tree/develop/linchpin/provision/roles/gcloud/vars>`_

Example Topology
+++++++++++++++++++++

`Example Topologies <http://linch-pin.readthedocs.io/en/latest/topologies.html>`_

Example Inventory Layout (openshift 3 node cluster)
+++++++++++++++++++++++++++++++++++++++++++++++++++

`Example Layouts <http://linch-pin.readthedocs.io/en/latest/config_layout.html>`_

Using Linch-Pin
+++++++++++++++

Probably the best way to see linch-pin in action, is to watch the
presentation given at
`DevConf 2017 <https://www.youtube.com/watch?v=Tb7Zti5Xao8>`_

